@@ -24,3 +24,14 @@ def wraps(data):
 
 def unwraps(data):
     return sisl_wrapper.SislWrapper().unwraps(data)
+
+
+class SislWrapper:
+    def __init__(self):
+        self.sisl = sisl_wrapper.SislWrapper()
+
+    def wraps(self, data):
+        return self.sisl.wraps(data)
+
+    def unwraps(self, data):
+        return self.sisl.unwraps(data)
