@@ -1,13 +1,13 @@
 # Copyright PA Knowledge Ltd 2021
 
 #
-# rYAMLfile       = grouping *WSP
+# rYAMLfile       = grouping *255WSP
 #
-# grouping        = "{" *WSP ( name ":" 1*WSP "!" type 1*WSP value *WSP *( "," *WSP name ":" 1*WSP "!" type 1*WSP value *WSP ) / "" ) "}​​​​​​"
+# grouping        = "{" *255WSP ( name ":" 1*255WSP "!" type 1*255WSP value *255WSP *( "," *255WSP name ":" 1*255WSP "!" type 1*255WSP value *255WSP ) / "" ) "}"
 #
 # name            = ( "_" / ALPHA ) *( "_" / "-" / "." / ALPHA / DIGIT )
 #
-# type            = ( "_" / ALPHA ) *( "_" / "-" / "." / ALPHA / DIGIT )
+# type            = ( "_" / ALPHA ) *254( "_" / "-" / "." / ALPHA / DIGIT )
 #
 # value           = ( DQUOTE *( PRINTABLE / ESCAPE) DQUOTE ) / grouping
 #
@@ -43,29 +43,29 @@ tokens = (
     'LIST_SEPARATOR'
 )
 
-t_BEGIN_OBJECT = '{[\s]*'
-t_END_OBJECT = '[\s]*}[\s]*'
-t_LIST_SEPARATOR = r'[\s]*,[\s]*'
+t_BEGIN_OBJECT = '{[\s]{0,255}'
+t_END_OBJECT = '[\s]{0,255}}[\s]{0,255}'
+t_LIST_SEPARATOR = r'[\s]{0,255},[\s]{0,255}'
 
 
 # name = ( "_" / ALPHA ) *( "_" / "-" / "." / ALPHA / DIGIT ):
 def t_NAME(t):
-    r'[_a-zA-Z][a-z0-9-\_\.]*:\s'
-    t.value = t.value[:-2]
+    r'[_a-zA-Z][a-zA-Z0-9-\_\.]*:[\s]{1,255}'
+    t.value = t.value.rstrip()[:-1]
     return t
 
 
-# type = ( "_" / ALPHA ) *( "_" / "-" / "." / ALPHA / DIGIT )
+# type = ( "_" / ALPHA ) *254( "_" / "-" / "." / ALPHA / DIGIT )
 def t_TYPE(t):
-    r'\![_a-zA-Z][a-z0-9-\_\.]*\s'
-    t.value = t.value[1:-1]
+    r'\![_a-zA-Z][a-zA-Z0-9-\_\.]{0,254}[\s]{1,255}'
+    t.value = t.value.rstrip()[1:]
     return t
 
 
 # value = ( DQUOTE *( PRINTABLE / ESCAPE) DQUOTE ) / grouping
 # ESCAPE = "\" ( LCR / LCT / LCN / DQUOTE / "\" / (LCX 2HEX) / (LCU 4HEX) / (UCU 8HEX) )
 def t_VALUE(t):
-    r'\".*?\"(?=\s*,|\s*\})'
+    r'"([^"\\]|\\.)*"(?=\s{0,255},|\s{0,255}})'
     t.value = t.value[1:-1]  # Remove quotation marks
     return t
 
