@@ -16,6 +16,7 @@ class SislWrapper:
         self.key = SislWrapper.key_generation() if key_generator is None else key_generator
         self.padding = 0
         self.cloaked_dagger = self._build_cloaked_dagger_header()
+        self.chunk_count = 0
 
     def wraps(self, data: str):
         return self.cloaked_dagger + SislWrapper._xor_data(self.key, SislWrapper._is_bytes(data))
@@ -31,11 +32,19 @@ class SislWrapper:
         else:
             raise TypeError("Input must be bytes")
 
-    @staticmethod
-    def unwraps(data):
-        CloakDagger.check_valid_cloaked_dagger_header(SislWrapper._is_bytes(data))
-        key = CloakDagger.get_cloak_dagger_field_by_name(data, 'Encap_Mask')
-        return SislWrapper._xor_data(key, SislWrapper._extract_payload_from_data(data))
+    def unwraps(self, data):
+        payload = self._get_payload(data)
+        unwrapped = SislWrapper._xor_data(self.key, payload)
+        self.chunk_count += 1
+        return unwrapped
+
+    def _get_payload(self, data):
+        if self.chunk_count == 0:
+            CloakDagger.check_valid_cloaked_dagger_header(SislWrapper._is_bytes(data))
+            self.key = CloakDagger.get_cloak_dagger_field_by_name(data, 'Encap_Mask')
+            return SislWrapper._extract_payload_from_data(data)
+        else:
+            return data
 
     @staticmethod
     def _extract_payload_from_data(data):
