@@ -5,7 +5,7 @@ from pysisl.sisl_decoder import SislDecoder, SislValidationError
 
 
 class SislParsingTests(unittest.TestCase):
-    def test_basic_sisl_structures_successful_parse(self):
+    def test_basic_sisl_structures(self):
         self.assertEqual({"abc": {"results": {"result": 123}}}, SislDecoder().loads("{abc: !obj {results: !obj {result: !int \"123\"}}}"))
 
     def test_successful_parse_with_schema(self):
@@ -36,10 +36,10 @@ class SislParsingTests(unittest.TestCase):
         self.assertRaises(SislValidationError,
                           SislDecoder().loads, "{field_one: !str \"string\", field_two: !int \"2\"}", schema=schema)
 
-    def test_sisl_with_escaped_backslash_successful_parse(self):
+    def test_sisl_with_escaped_backslash(self):
         self.assertEqual({"abc": "te\\st"}, SislDecoder().loads("{abc: !str \"te\\st\"}"))
 
-    def test_sisl_with_escaped_quotes_successful_parse(self):
+    def test_sisl_with_escaped_quotes(self):
         self.assertEqual({"abc": "te\"st"}, SislDecoder().loads(r'{abc: !str "te\"st"}'))
 
     def test_escaped_backslash_before_closing_quote_sisl(self):
@@ -48,15 +48,24 @@ class SislParsingTests(unittest.TestCase):
     def test_escaped_quote_before_closing_quote_sisl(self):
         self.assertEqual({"abc": "test\""}, SislDecoder().loads(r'{abc: !str "test\""}'))
 
-    def test_sisl_with_8_bit_unicode_successful_parse(self):
+    def test_sisl_with_8_bit_unicode(self):
         self.assertEqual({"abc": "çä"}, SislDecoder().loads(r'{abc: !str "\xe7\xe4"}'))
 
-    def test_sisl_with_16_bit_unicode_successful_parse(self):
+    def test_sisl_with_16_bit_unicode(self):
         self.assertEqual({"abc": "ӧʶ"}, SislDecoder().loads(r'{abc: !str "\u04e7\u02b6"}'))
 
-    def test_sisl_with_32_bit_unicode_successful_parse(self):
+    def test_sisl_with_32_bit_unicode(self):
         self.assertEqual({"abc": "😂🔥"}, SislDecoder().loads(r'{abc: !str "\U0001f602\U0001f525"}'))
 
+    def test_sisl_with_anonymous_string(self):
+        self.assertEqual("i_am_a_string", SislDecoder().loads(r'{_: !_str "i_am_a_string"}'))
+
+    def test_sisl_with_anonymous_unicode_string(self):
+        self.assertEqual("😂", SislDecoder().loads(r'{_: !_str "\U0001f602"}'))
+
+    def test_sisl_with_anonymous_list(self):
+        self.assertEqual([1,2,3], SislDecoder().loads(['{_: !_list {_0: !int "1", _1: !int "2", _2: !int "3"}}']))
+
     def test_basic_split_sisl_string_parsed_using_joiner(self):
         self.assertEqual({"abc": 2, "def": 3}, SislDecoder().loads(['{abc: !int "2"}', '{def: !int "3"}']))
 
