@@ -8,6 +8,9 @@ class SislFlatteningTests(unittest.TestCase):
     def test_basic_sisl_structures(self):
         self.assertEqual({"abc": "stuff"}, SISLTypeFlatten.flatten({"abc": {"type": "str", "value": "stuff"}}))
 
+    def test_anonymous_string(self):
+        self.assertEqual("stuff", SISLTypeFlatten.flatten({"_": {"type": "_str", "value": "stuff"}}))
+
     def test_bool(self):
         self.assertEqual({"abc": True}, SISLTypeFlatten.flatten({"abc": {"type": "bool", "value": "true"}}))
         self.assertEqual({"abc": False}, SISLTypeFlatten.flatten({"abc": {"type": "bool", "value": "false"}}))
@@ -67,6 +70,22 @@ class SislFlatteningTests(unittest.TestCase):
                                                      "_2": {"type": "int", "value": "4"},
                                                      "_3": {"type": "int", "value": "5"}}}}}}}}}}))
 
+    def test_single_element_anonymous_list(self):
+        self.assertEqual([1], SISLTypeFlatten.flatten({"_": {"type": "_list", "value": {"_0": {"type": "int", "value": "1"}}}}))
+
+    def test_two_element_anonymous_list(self):
+        self.assertEqual([1, 5], SISLTypeFlatten.flatten(
+            {"_": {"type": "_list", "value": {
+                "_0": {"type": "int", "value": "1"},
+                "_1": {"type": "int", "value": "5"}
+            }}}))
+
+        self.assertEqual([[1], [5]], SISLTypeFlatten.flatten(
+            {"_": {"type": "_list", "value": {
+                "_0": {"type": "list", "value": {"_0": {"type": "int", "value": "1"}}},
+                "_1": {"type": "list", "value": {"_0": {"type": "int", "value": "5"}}}
+            }}}))
+
     def test_none_type(self):
         self.assertEqual({"abc": None}, SISLTypeFlatten.flatten({"abc": {"type": "null", "value": ""}}))
 
